@@ -6,6 +6,7 @@ use strict;
 use warnings;
 
 use Test::More;
+use Test::Warn;
 
 use constant UNKNOWN_PARAMS => (-verzeichnis => SIMPLE_DIR,
                                 -ueberpruefe => qr/deutsch/,
@@ -20,16 +21,10 @@ sub warning_when_unknown_param : Test(8) {
     my $self = shift;
     my %params = UNKNOWN_PARAMS;
     while (my @args = each %params) {
-        warns_ok( sub {$self->random_file(@args)}, "Arguments: @args");
+        warning_like {$self->random_file(@args)} 
+                     [{carped => qr/unknown option/i}],
+                     "Arguments: @args"; 
     }
 }
 
-sub warns_ok {
-    my ($sub, $testname) = @_;
-    my $has_warned = 0;
-    local $SIG{__WARN__} = sub {$has_warned = 1};
-    $sub->();
-    ok $has_warned, "Expected warning failed: $testname";
-}
-
 1;
